@@ -376,7 +376,7 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="localhost",
+    connection = connect(host="54.237.240.43",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
